perfutils

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LogMemUsage

func LogMemUsage(ctx context.Context)

LogMemUsage logs a one-off snapshot of runtime memory and GC statistics at info level using the ctx logger.

func SpamLogMemUsage

func SpamLogMemUsage(ctx context.Context, d time.Duration)

SpamLogMemUsage calls LogMemUsage every d until ctx is cancelled. It blocks, so run it in its own goroutine.

Types

This section is empty.

Jump to